pub struct SslStream<S> { /* private fields */ }Expand description
Compio asynchronous version of openssl:ssl::SslStream.
Implementations
Sourceimpl<S: AsyncRead + AsyncWrite> SslStream<S>
impl<S: AsyncRead + AsyncWrite> SslStream<S>
Sourcepub fn new(ssl: Ssl, stream: S) -> Result<SslStream<S>, ErrorStack>
pub fn new(ssl: Ssl, stream: S) -> Result<SslStream<S>, ErrorStack>
Create a new SslStream.
Reference: SslStream::new
Sourcepub fn get_mut(&mut self) -> &mut S
pub fn get_mut(&mut self) -> &mut S
Get a mutable reference to the underlying stream.
Warning
Any read/write operation to the stream would most likely corrupt the SSL session.
Sourcepub fn ssl(&self) -> &SslRef
pub fn ssl(&self) -> &SslRef
Returns a shared reference to the Ssl object associated with this stream.
Sourcepub async fn accept(&mut self) -> Result<()>
pub async fn accept(&mut self) -> Result<()>
Initiates a server-side TLS handshake.
Reference: SslStream::accept
Sourcepub async fn connect(&mut self) -> Result<()>
pub async fn connect(&mut self) -> Result<()>
Initiates a server-side TLS handshake.
Reference: SslStream::connect
Sourcepub async fn read_realy_data(&mut self, buf: &mut [u8]) -> Result<usize>
pub async fn read_realy_data(&mut self, buf: &mut [u8]) -> Result<usize>
Read application data transmitted by a client before handshake completion.
Useful for reducing latency, but vulnerable to replay attacks.
Returns Ok(0) if all early data has been read.
Reference: SslStream::read_early_data
Sourcepub async fn write_realy_data(&mut self, buf: &[u8]) -> Result<usize>
pub async fn write_realy_data(&mut self, buf: &[u8]) -> Result<usize>
Send data to the server without blocking on handshake completion.
Useful for reducing latency, but vulnerable to replay attacks.
Reference: SslStream::write_early_data
Sourcepub async fn peek(&mut self, buf: &mut [u8]) -> Result<usize>
pub async fn peek(&mut self, buf: &mut [u8]) -> Result<usize>
Reads data from the stream, without removing it from the queue.
Reference: SslStream::ssl_peek
Sourcepub fn get_shutdown(&mut self) -> ShutdownState
pub fn get_shutdown(&mut self) -> ShutdownState
Returns the session’s shutdown state.
Sourcepub fn set_shutdown(&mut self, state: ShutdownState)
pub fn set_shutdown(&mut self, state: ShutdownState)
Sets the session’s shutdown state.
This can be used to tell OpenSSL that the session should be cached even if a full two-way shutdown was not completed.
Sourcepub async fn stateless(&mut self) -> Result<bool, ErrorStack>
pub async fn stateless(&mut self) -> Result<bool, ErrorStack>
Perform a stateless server-side handshake.
Requires that cookie generation and verification callbacks were set on the SSL context.
Returns Ok(true) if a complete ClientHello containing a valid cookie
was read, in which case the handshake should be continued via
accept. If a HelloRetryRequest containing a fresh cookie was
transmitted, Ok(false) is returned instead. If the handshake cannot
proceed at all, Err is returned.